==> wasabiD-0.2.92.tgz: package/Base/Form/SearchBar.jsx <==
//create by wangzy
//date:2016-02-24
//desc:页面筛选条件组件
require(".././SearchBar.scss");
var React=require("react");
var Input=require("./Input.jsx");
var Button=require("../Button/Button.jsx");
var alogUtil=require("../../libs/alogUtil.js");
var SearchBar=React.createClass({
    propTypes: {
        model:React.PropTypes.array.isRequired,
        searchTitle:React.PropTypes.string,
        searchHide:React.PropTypes.bool,
        filterHandler:React.PropTypes.func.isRequired,
        expandHandler:React.PropTypes.func,

    },
    getDefaultProps:function() {
        return {
            model: [],//表单数据模型
            searchTitle:"查询",//查询按钮的标题
            searchHide:false,//是否隐藏按钮
            filterHandler: null,//提交成功后的回调事件
            className:"",
            expandHandler:null,//展开与折叠事件

        }

    },
    getInitialState:function() {
        let showDrop=false;
       this.sum=this.props.model.length;
        if(this.props.model.length<4)
        {

        }
        else {
            for(let index=0;index<this.props.model.length;index++)
            {
                if(this.props.model[index].hide==true)
                {
                    this.sum--;
                }
            }
            if(this.sum<4)
            {

            }
            else
            {
                if((this.props.model.length*310+132)>document.body.clientWidth)
                {
                    showDrop=true;
                }
            }

        }
        return{
            model:(this.props.model),
            showDrop:showDrop,//超过四个查询条件就显示折叠按钮
            dropType:"Button searchbar-down"//折叠按钮样式
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
        model:(nextProps.model),
        style:nextProps.style,
        className:nextProps.className,

    });
        //this.forceUpdate();//?强制刷新
    },
    changeHandler:function(value,text,name) {
        //子组件值发生改变时
        var newModel=this.state.model;
        for(var i=0;i<newModel.length;i++)
        {
            if(newModel[i].name==name)
            {
                newModel[i].value=value;
                newModel[i].text=text;
                break ;
            }
        }
        this.setState({
            model:newModel
        })
    },
    clearData:function() {//清空数据
        var newModel=this.state.model;
        for(let i=0;i<newModel.length;i++)
        {
            newModel[i].value=null;
            newModel[i].text=null;
        }
        this.setState({
            model:newModel
        })
    },
    getData:function() {
        var data={}
        for(let v in this.refs) {
            if(this.refs[v].props.name.indexOf(",")>-1)
            {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {
                    var valueSplit=this.refs[v].state.value.split(",");
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<valueSplit.length)
                        {
                            data[nameSplit[index]]=valueSplit[index];
                        }
                    }

                }
                else {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            data[nameSplit[index]]=null;
                    }
                }
            }
            else
            {
                data[this.refs[v].props.name]=this.refs[v].state.value;
            }

        }
        return data;
    },
    getTextData:function() {
        var textData={};//各个字段对应的文本值
        for(let v in this.refs)
        {
            if(this.refs[v].props.name.indexOf(",")>-1) {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {

                    var textSplit=this.refs[v].state.text.split(",");//文本值
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<textSplit.length)
                        {
                            textData[nameSplit[index]]=textSplit[index];
                        }
                    }

                }  else {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            textData[nameSplit[index]]="";

                    }
                }
            }
            else
            {
                textData[this.refs[v].props.name]=this.refs[v].state.text;


            }

        }
        return textData;
    },
    onSubmit:function() {
    //筛选查询开始
        var data={};//各个字段对应的值
        var textData={};//各个字段对应的文本值
        let isva=true;
        for(let v in this.refs) {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }
            if(this.refs[v].props.name.indexOf(",")>-1)
            {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {
                    var valueSplit=this.refs[v].state.value.split(",");
                    var textSplit=this.refs[v].state.text.split(",");//文本值
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<valueSplit.length)
                        {
                            data[nameSplit[index]]=valueSplit[index];
                            textData[nameSplit[index]]=textSplit[index];
                        }
                    }

                }
                else {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            data[nameSplit[index]]=null;
                            textData[nameSplit[index]]="";
                    }
                }
            }
            else
            {
                data[this.refs[v].props.name]=this.refs[v].state.value;
                textData[this.refs[v].props.name]=this.refs[v].state.text;

            }

        }
        if(isva) {
            this.props.filterHandler(data,textData);
        }
    },
    getComponentData:function(name) {//只读属性，获取对应的字段的数据源
        return JSON.parse( window.localStorage.getItem(name+"data"));
    },
    expandHandler:function() {
        var expand=false;
     if(this.state.dropType=="Button searchbar-down") {
         this.setState({
             dropType:"Button searchbar-up"

         });
         expand=true;
     }
        else {
         this.setState({
             dropType:"Button searchbar-down"
         });
     }
        if(this.props.expandHandler!=null)
        {
          this.props.expandHandler(expand);
        }

    },
    render:function() {
     var column=parseInt((document.body.clientWidth-132-10)/300);
        if(this.state.model instanceof Array)
        {
        }
        else
        {
            return( <div></div>);
        }
            if(this.sum<column)
        {
            column=this.sum;
        }
        let props={
            className:"searchbar "+(this.state.dropType=="Button searchbar-down"?"":"all")+" "+this.props.className,
             style:this.props.style
                   };
        return (
            <div {...props}>
                <div style={{width:300*column,display:"inline-block",float:"left"}}  >
                {
                    this.state.model.map(  (child,i)=> {
                   return(  <div key={"searchbar"+i}  style={{display:(this.state.showDrop==true?((this.state.dropType.indexOf("down")>-1&&column<=i)?"none":"inline"):"inline")}}>
                       <Input ref={child.name}
                              key={child.name+i.toString()}
                              {...child}
                              backFormHandler={this.changeHandler}
                        ></Input></div>);

                    })
                }
            </div>
            <div style={{marginTop:-10}}>
                            <button className={this.state.dropType} style={{display:this.state.showDrop?"inline":"none"}} onClick={this.expandHandler}  ></button>
                            <Button  onClick={this.onSubmit.bind(this,"submit")} style={{marginTop:"10px",display:this.props.searchHide==true?"none":null}} title={this.props.searchTitle}   >
                                {this.props.searchTitle}
                            </Button>
                </div>
             </div>

        )
    }
});
module.exports=SearchBar;

==> wasabiD-0.2.983.tgz: package/Base/Form/SearchBar.jsx <==
//create by wangzy
//date:2016-02-24
//desc:页面筛选条件组件
require("../../sass/Base/Form/SearchBar.scss");
var React=require("react");
var Input=require("./Input.jsx");
var Button=require("../Buttons/Button.jsx");
var unit=require("../../libs/unit.js");
var SearchBar=React.createClass({
    propTypes: {
        model:React.PropTypes.array.isRequired,
        searchTitle:React.PropTypes.string,
        searchHide:React.PropTypes.bool,
        filterHandler:React.PropTypes.func.isRequired,
        expandHandler:React.PropTypes.func,

    },
    getDefaultProps:function() {
        return {
            model: [],//表单数据模型
            searchTitle:"查询",//查询按钮的标题
            searchHide:false,//是否隐藏按钮
            filterHandler: null,//提交成功后的回调事件
            className:"",
            expandHandler:null,//展开与折叠事件

        }

    },
    getInitialState:function() {
        let showDrop=false;
       this.sum=this.props.model.length;
        if(this.props.model.length<4)
        {

        }
        else {
            for(let index=0;index<this.props.model.length;index++)
            {
                if(this.props.model[index].hide==true)
                {
                    this.sum--;
                }
            }
            if(this.sum<4)
            {

            }
            else
            {
                if((this.props.model.length*310+132)>document.body.clientWidth)
                {
                    showDrop=true;
                }
            }

        }
        return{
            model:(this.props.model),
            showDrop:showDrop,//超过四个查询条件就显示折叠按钮
            dropType:"Buttons searchbar-down"//折叠按钮样式
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
        model:(nextProps.model),
        style:nextProps.style,
        className:nextProps.className,

    });
        //this.forceUpdate();//?强制刷新
    },
    changeHandler:function(value,text,name) {
        //子组件值发生改变时
        var newModel=this.state.model;
        for(var i=0;i<newModel.length;i++)
        {
            if(newModel[i].name==name)
            {
                newModel[i].value=value;
                newModel[i].text=text;
                break ;
            }
        }
        this.setState({
            model:newModel
        })
    },
    clearData:function() {//清空数据
        var newModel=this.state.model;
        for(let i=0;i<newModel.length;i++)
        {
            newModel[i].value=null;
            newModel[i].text=null;
        }
        this.setState({
            model:newModel
        })
    },
    getData:function() {
        var data={}
        for(let v in this.refs) {
            if(this.refs[v].props.name.indexOf(",")>-1)
            {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {
                    var valueSplit=this.refs[v].state.value.split(",");
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<valueSplit.length)
                        {
                            data[nameSplit[index]]=valueSplit[index];
                        }
                    }

                }
                else {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            data[nameSplit[index]]=null;
                    }
                }
            }
            else
            {
                data[this.refs[v].props.name]=this.refs[v].state.value;
            }

        }
        return data;
    },
    getTextData:function() {
        var textData={};//各个字段对应的文本值
        for(let v in this.refs)
        {
            if(this.refs[v].props.name.indexOf(",")>-1) {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {

                    var textSplit=this.refs[v].state.text.split(",");//文本值
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<textSplit.length)
                        {
                            textData[nameSplit[index]]=textSplit[index];
                        }
                    }

                }  else {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            textData[nameSplit[index]]="";

                    }
                }
            }
            else
            {
                textData[this.refs[v].props.name]=this.refs[v].state.text;


            }

        }
        return textData;
    },
    onSubmit:function() {
    //筛选查询开始
        var data={};//各个字段对应的值
        var textData={};//各个字段对应的文本值
        let isva=true;
        for(let v in this.refs) {
            if(isva) {
                //验证成功，则继续验证
                isva = this.refs[v].validate(this.refs[v].state.value);
            }else
            {//不成功则继续验证但不再回执
                this.refs[v].validate(this.refs[v].state.value);
            }
            if(this.refs[v].props.name.indexOf(",")>-1)
            {//含有多个字段
                var nameSplit=this.refs[v].props.name.split(",");
                if(this.refs[v].state.value&&this.refs[v].state.value!="")
                {
                    var valueSplit=this.refs[v].state.value.split(",");
                    var textSplit=this.refs[v].state.text.split(",");//文本值
                    for(let index =0;index<nameSplit.length;index++)
                    {
                        if(index<valueSplit.length)
                        {
                            data[nameSplit[index]]=valueSplit[index];
                            textData[nameSplit[index]]=textSplit[index];
                        }
                    }

                }
                else {
                    for(let index =0;index<nameSplit.length;index++)
                    {
                            data[nameSplit[index]]=null;
                            textData[nameSplit[index]]="";
                    }
                }
            }
            else
            {
                data[this.refs[v].props.name]=this.refs[v].state.value;
                textData[this.refs[v].props.name]=this.refs[v].state.text;

            }

        }
        if(isva) {
            this.props.filterHandler(data,textData);
        }
    },
    getComponentData:function(name) {//只读属性，获取对应的字段的数据源
        return JSON.parse( window.localStorage.getItem(name+"data"));
    },
    expandHandler:function() {
        var expand=false;
     if(this.state.dropType=="Buttons searchbar-down") {
         this.setState({
             dropType:"Buttons searchbar-up"

         });
         expand=true;
     }
        else {
         this.setState({
             dropType:"Buttons searchbar-down"
         });
     }
        if(this.props.expandHandler!=null)
        {
          this.props.expandHandler(expand);
        }

    },
    render:function() {
     var column=parseInt((document.body.clientWidth-132-10)/300);
        if(this.state.model instanceof Array)
        {
        }
        else
        {
            return( <div></div>);
        }
            if(this.sum<column)
        {
            column=this.sum;
        }
        let props={
            className:"searchbar "+(this.state.dropType=="Buttons searchbar-down"?"":"all")+" "+this.props.className,
             style:this.props.style
                   };
        return (
            <div {...props}>
                <div style={{width:300*column,display:"inline-block",float:"left"}}  >
                {
                    this.state.model.map(  (child,i)=> {
                   return(  <div key={"searchbar"+i}  style={{display:(this.state.showDrop==true?((this.state.dropType.indexOf("down")>-1&&column<=i)?"none":"inline"):"inline")}}>
                       <Input ref={child.name}
                              key={child.name+i.toString()}
                              {...child}
                              backFormHandler={this.changeHandler}
                        ></Input></div>);

                    })
                }
            </div>
            <div style={{marginTop:-10}}>
                            <button className={this.state.dropType} style={{display:this.state.showDrop?"inline":"none"}} onClick={this.expandHandler}  ></button>
                            <Button  onClick={this.onSubmit.bind(this,"submit")} style={{marginTop:"10px",display:this.props.searchHide==true?"none":null}} title={this.props.searchTitle}   >
                                {this.props.searchTitle}
                            </Button>
                </div>
             </div>

        )
    }
});
module.exports=SearchBar;
